% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Eno.R
\name{Eno}
\alias{Eno}
\title{Compute Effective Sample Size With Classical Method}
\usage{
Eno(data, sdate_dim = "sdate", na.action = na.pass, ncores = NULL)
}
\arguments{
\item{data}{A numeric array with named dimensions.}

\item{sdate_dim}{A function indicating the dimension along 
which to compute the effective sample size. Default value is 'sdate'.}

\item{na.action}{A charater string indicating the action for missing values,
can be na.pass (missing values are allowed) or na.fail (no missing values 
are allowed). See details in stats::acf(). Default value is 'na.pass'.}

\item{ncores}{An integer indicating the number of cores to use for parallel 
computation. Default value is NULL.}
}
\value{
An array with the first dimension 'stats', which is the number of 
 effective samples, and the following dimensions same as parameter 'data' 
 except the sdate_dim dimension.
}
\description{
Compute the number of effective samples along one dimension of an array. This
effective number of independent observations can be used in statistical/inference 
tests.\cr
The calculation is based on eno function from Caio Coelho from rclim.txt.
}
\examples{
set.seed(1)
data <- array(rnorm(800), dim = c(dataset = 1, member = 2, sdate = 4, 
                                 ftime = 4, lat = 10, lon = 10))
na <- floor(runif(40, min=1, max=800))
data[na] <- NA
res <- Eno(data)

}
\author{
History:\cr
0.1  -  2011-05  (V. Guemas, \email{virginie.guemas@ic3.cat})  -  Original code\cr
1.0  -  2013-09  (N. Manubens, \email{nicolau.manubens@ic3.cat})  -  Formatting to R CRAN
3.0  -  2019-12  (A. Ho, \email{an.ho@bsc.es})  - Adopt multiApply
}
\keyword{datagen}

